#
# spec file for package desktopfolder
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define         appid com.github.spheras.desktopfolder
Name:           desktopfolder
Version:        1.1.3
Release:        4.1
Summary:        Tool for organizing the desktop with panels, notes and photos
License:        GPL-3.0-or-later
URL:            https://github.com/spheras/desktopfolder
Source:         %{url}/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
# PATCH-FIX-UPSTREAM -- https://github.com/spheras/desktopfolder/pull/328
Patch0:         000-drop-gsettings-schema.patch
# PATCH-FIX-UPSTREAM -- https://github.com/spheras/desktopfolder/pull/328
Patch1:         001-dark-mode-support.patch
# PATCH-FIX-UPSTREAM -- https://github.com/spheras/desktopfolder/pull/335/commits
Patch2:         002-drop-deprecated-arguments.patch
BuildRequires:  fdupes
BuildRequires:  hicolor-icon-theme
BuildRequires:  intltool
BuildRequires:  meson >= 0.40.0
BuildRequires:  pkgconfig
BuildRequires:  vala
BuildRequires:  pkgconfig(cairo)
BuildRequires:  pkgconfig(gdk-pixbuf-2.0)
BuildRequires:  pkgconfig(gee-0.8)
BuildRequires:  pkgconfig(gio-unix-2.0)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gobject-2.0)
BuildRequires:  pkgconfig(granite) >= 6.0.0
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.22
BuildRequires:  pkgconfig(gtksourceview-3.0)
BuildRequires:  pkgconfig(json-glib-1.0)
BuildRequires:  pkgconfig(libwnck-3.0)

%description
A program with which the desktop can be organized with panels that hold things.
  * Access files, folders and apps from your desktop
  * Drop files, folders, links and .desktop launchers inside panels
  * Resize, position and color panels
  * Display photos and keep notes on your desktop
  * Reveal the desktop with ⌘-D (Command-D)

%lang_package

%prep
%autosetup -p1

%build
%meson
%meson_build

%install
%meson_install
%find_lang %{appid}

# https://github.com/spheras/desktopfolder/issues/69
find %{buildroot} -name '*.svg' -exec chmod 0644 {} \;

%if 0%{?suse_version} >= 1600
mkdir -p %{buildroot}%{_distconfdir}/xdg/autostart
mv %{buildroot}%{_sysconfdir}/xdg/autostart/%{appid}-autostart.desktop \
   %{buildroot}%{_distconfdir}/xdg/autostart/%{appid}-autostart.desktop
%endif

%fdupes -s %{buildroot}

%files
%license LICENSE
%doc AUTHORS.md README.md
%{_bindir}/%{appid}
%{_datadir}/applications/%{appid}.desktop
%{_datadir}/glib-2.0/schemas/%{appid}.gschema.xml
%{_datadir}/icons/hicolor/*/apps/%{appid}.svg
%{_datadir}/metainfo/%{appid}.appdata.xml
%if 0%{?suse_version} >= 1600
%{_distconfdir}/xdg/autostart/%{appid}-autostart.desktop
%else
%{_sysconfdir}/xdg/autostart/%{appid}-autostart.desktop
%endif

%files lang -f %{appid}.lang

%changelog
* Sun Nov 17 2024 Richard Rahl <rrahl0@opensuse.org>
- update spec file for Leap 16.0:
  * remove %%suse_update_desktop_file
  * remove lang package from recommends
  * use autosetup
  * mv autostart desktop file to /usr/etc
* Sun Feb 20 2022 Alexei Podvalsky <avvissu@yandex.by>
- Add 002-drop-deprecated-arguments.patch
* Fri Oct  8 2021 Alexei Podvalsky <avvissu@yandex.by>
- Add 000-drop-gsettings-schema.patch
- Add 001-dark-mode-support.patch
- Spec file cleanup
* Wed Sep  9 2020 Alexei Podvalsky <avvissu@yandex.by>
- Update to 1.1.3:
  * fix: removed ubuntu installations post scripts
  * fix: houston ci node version
  * fix: transparent icons on changing desktops
  * fix: fast double click (issue #293)
  * fix: black backdrop on Fedora (issue #297)
  * Translations Added and Updated
* Mon Jan 13 2020 Alexei Podvalsky <avvissu@yandex.by>
- Update to 1.1.2:
  * Merge pull request #281 from JoshStrobl/vala_compilation_fix
  * Merge pull request #279 from UbuntuBudgie/itemviewcleanup
  * Merge pull request #278 from UbuntuBudgie/photoopen
  * Fix compilation against Vala 0.46
  * Remove unnecessary separators from note menu
  * Remove unneeded window parent from menuitemcolor
  * Fix crash due to null parent window
  * Fix padding for color menu item to be consistent with other
    menu items
  * Make FolderWindow menu consistent with other submenus
  * Remove unnecessary separate for photo menu
  * Recombine panel properties menu options
  * Reorganise menu to combine actions
  * Add double click on photo to open in default viewer #277
  * Add popup option to open photo in default viewer
  * Merge pull request #274 from UbuntuBudgie/autostart
  * Let GSD handle starting/not starting desktopfolder via
    autostart
  * Merge branch 'master' of
    https://github.com/spheras/desktopfolder
  * close #272
  * Update fr.po
  * Merge pull request #259 from UbuntuBudgie/vala44
  * Fix compilation issues with vala 0.44
- Drop desktopfolder-1.1.1-vala-0.44.patch
- Drop desktopfolder-1.1.1-vala-0.46.patch
* Wed Oct 30 2019 Alexei Podvalsky <avvissu@yandex.by>
- Add desktopfolder-1.1.1-vala-0.46.patch
* Wed Aug  7 2019 Alexei Podvalsky <avvissu@yandex.by>
- Add OnlyShowIn=Pantheon to *.autostart.desktop
* Sun May 12 2019 Alexei Podvalsky <avvissu@yandex.by>
- Add desktopfolder-1.1.1-vala-0.44.patch
* Mon Mar 11 2019 Alexei Podvalsky <avvissu@yandex.by>
- Update to 1.1.1:
  * appdata updated
* Mon Feb 18 2019 Alexei Podvalsky <avvissu@yandex.by>
- Update to 1.1.0:
  * header custom style bugfix
  * removing debug lines
  * folder search bugfixing
  * dragdrop optimization
  * minor right window resize bugfixing
  * close issue #250
  * close issue #244
  * issue #211, improved desktop panel position taking into
    account docks like plank
  * first version of multiselection, reference #118 issue
  * fix issue #240 check whether the item could be executable or not
  * possible solution to issue #238
  * show loading outside thread
  * delete key to remove panels commented (I feel it is too
    drastic)
  * Merge pull request #235 from lvitals/fix_new_folder
  * Fix problem by creating new folders
  * Give travis intltool to chew on
- Spec file cleanup
* Sun Nov 11 2018 Alexei Podvalsky <avvissu@yandex.by>
- Update to 1.0.10:
  * Removed first folder setting. Not needed due to desktop panel
    condition. #121
  * issue #136, allow change icon for everything
  * Merge pull request #137 from UbuntuBudgie/svg
  * Full path icon display and SVG choose icon support #135
  * moving debian to deb-packaging branch
  * uncrustifying
  * Fix typos that check-all-the-things reported
  * Resolve appstreamcli validate issues
  * menu item color right space
  * issue #131 - magic numbers
  * Allow desktop configuration apps to stop showing
    desktopfolder #126
  * updated to Gtk+3.22, replacing old deprecated methods
  * close #123 open wallpaper settings for pantheon and gnome
    derivatives
  * removed deprecated gtk functions <3.12
  * adjusting note title label margins
  * Ensure all source files have an up-to-date copyright statement
* Mon Oct 22 2018 Jan Engelhardt <jengelh@inai.de>
- Use noun phrase in descriptions.
* Tue Oct 16 2018 Alexei Podvalsky <avvissu@yandex.by>
- Update to 1.0.9:
  * minor bugfixing
* Mon Oct  8 2018 Alexei Podvalsky <avvissu@yandex.by>
- Update to 1.0.7:
  * Change Wallpaper from Desktop right click
  * Dutch Translation by @Vistaus
  * Improved Russian Translation by @ingumsky
  * Updated project for GTK 3.22 and Elementary Juno
  * Minor Bugfixing
* Fri Mar  2 2018 avvissu@yandex.by
- Update to 1.0.6:
  * version parameter
  * custom desktop folder name
  * changes:~ files ignored improved saving performance
  * italian language
* Sat Jan  6 2018 avvissu@yandex.by
- Update to 1.0.5:
  * fake desktop update status automatically bugfixing
  * existent setting property bugfixing
  * fake desktop removed when property changed
  * note back and top bugfixing
  * Note rename popup bugfixing
  * issue #90 - Drag & drop breaks after dragging & dropping an
    item between panels
  * Update lt.po
  * properties dialog modal #87 lock panel -header bugfix
  * improved notes and photos json modifications
  * Add libjson-glib-dev to dependency list in README
  * updated authors and changelog
* Tue Nov  7 2017 avvissu@yandex.by
- Initial package
